summaryrefslogtreecommitdiff
path: root/baobab/src/baobab-utils.c
diff options
context:
space:
mode:
Diffstat (limited to 'baobab/src/baobab-utils.c')
-rw-r--r--baobab/src/baobab-utils.c32
1 files changed, 17 insertions, 15 deletions
diff --git a/baobab/src/baobab-utils.c b/baobab/src/baobab-utils.c
index 5aaec321..43efd3fb 100644
--- a/baobab/src/baobab-utils.c
+++ b/baobab/src/baobab-utils.c
@@ -1,26 +1,25 @@
-/*
- * baobab-utils.c
- * This file is part of baobab
+/* Copyright (C) 2005-2006 Fabio Marzocca <[email protected]>
+ * Copyright (C) 2012-2021 MATE Developers
*
- * Copyright (C) 2005-2006 Fabio Marzocca <[email protected]>
+ * This file is part of MATE Utils.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301 USA
+ * along with MATE Utils. If not, see <https://www.gnu.org/licenses/>.
*/
+#ifdef HAVE_CONFIG_H
#include <config.h>
+#endif
#include <glib.h>
#include <glib/gstdio.h>
@@ -34,6 +33,8 @@
#include <glibtop/mountlist.h>
#include <glibtop/fsusage.h>
+#include <libmate-desktop/mate-image-menu-item.h>
+
#include "baobab.h"
#include "baobab-treeview.h"
#include "baobab-utils.h"
@@ -71,7 +72,7 @@ baobab_get_filesystem (BaobabFS *fs)
g_free (mountentries);
}
-void
+static void
filechooser_cb (GtkWidget *chooser,
gint response,
gpointer data)
@@ -324,9 +325,9 @@ add_popupmenu_item (GtkMenu *pmenu, const gchar *label, const gchar *icon_name,
GtkWidget *item;
GtkWidget *image;
- item = gtk_image_menu_item_new_with_mnemonic (label);
+ item = mate_image_menu_item_new_with_mnemonic (label);
image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
- gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
+ mate_image_menu_item_set_image (MATE_IMAGE_MENU_ITEM (item), image);
g_signal_connect (item, "activate", item_cb, NULL);
@@ -499,8 +500,9 @@ baobab_help_display (GtkWindow *parent,
gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
"%s", error->message);
- g_signal_connect (G_OBJECT (dialog), "response",
- G_CALLBACK (gtk_widget_destroy), NULL);
+ g_signal_connect (dialog, "response",
+ G_CALLBACK (gtk_widget_destroy),
+ NULL);
gtk_widget_show (dialog);
@@ -1,26 +1,25 @@
*
- * This program is free software; you can redistribute it and/or modify
+ * MATE Utils is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -1,26 +1,25 @@
* (at your option) any later version.
*
- * This program is distributed in the hope that it will be useful,
+ * MATE Utils is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the